==> chromium-52.0.2729.3.tar.xz: chromium-52.0.2729.3/chrome/browser/resources/md_extensions/item_list.js <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

cr.define('extensions', function() {
  var ItemList = Polymer({
    is: 'extensions-item-list',

    behaviors: [
      Polymer.NeonAnimatableBehavior,
      Polymer.IronResizableBehavior
    ],

    properties: {
      animationConfig: {
        type: Object,
        value: function() {
          return {
            exit: [{
              name: 'hero-animation',
              id: 'hero',
              fromPage: this,
            }],
          };
        },
      },

      /** @type {Array<!chrome.developerPrivate.ExtensionInfo>} */
      items: Array,

      /** @type {extensions.ItemDelegate} */
      delegate: Object,

      inDevMode: {
        type: Boolean,
        value: false,
      },

      filter: String,
    },

    listeners: {
      'list.extension-item-size-changed': 'itemSizeChanged_',
      'list.extension-item-show-details': 'showItemDetails_',
    },

    /**
     * Updates the size for a given item.
     * @param {CustomEvent} e
     * @private
     * @suppress {checkTypes} Closure doesn't know $.list is an IronList.
     */
    itemSizeChanged_: function(e) {
      this.$.list.updateSizeForItem(e.detail.item);
    },

    /**
     * Called right before an item enters the detailed view.
     * @param {CustomEvent} e
     * @private
     */
    showItemDetails_: function(e) {
      this.sharedElements = {hero: e.detail.element};
    },

    /**
     * Computes the list of items to be shown.
     * @param {Object} changeRecord The changeRecord for |items|.
     * @param {string} filter The updated filter string.
     * @return {Array<!chrome.developerPrivate.ExtensionInfo>}
     * @private
     */
    computeShownItems_: function(changeRecord, filter) {
      return this.items.filter(function(item) {
        return item.name.toLowerCase().includes(this.filter.toLowerCase());
      }, this);
    },
  });

  return {
    ItemList: ItemList,
  };
});

==> chromium-55.0.2883.76.tar.xz: chromium-55.0.2883.76/chrome/browser/resources/md_extensions/item_list.js <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

cr.define('extensions', function() {
  var ItemList = Polymer({
    is: 'extensions-item-list',

    behaviors: [
      Polymer.NeonAnimatableBehavior,
      Polymer.IronResizableBehavior
    ],

    properties: {
      /** @type {Array<!chrome.developerPrivate.ExtensionInfo>} */
      items: Array,

      /** @type {extensions.ItemDelegate} */
      delegate: Object,

      inDevMode: {
        type: Boolean,
        value: false,
      },

      filter: String,
    },

    listeners: {
      'list.extension-item-size-changed': 'itemSizeChanged_',
    },

    ready: function() {
      /** @type {extensions.AnimationHelper} */
      this.animationHelper = new extensions.AnimationHelper(this, this.$.list);
      this.animationHelper.setEntryAnimation(extensions.Animation.FADE_IN);
      this.animationHelper.setExitAnimation(extensions.Animation.HERO);
    },

    /**
     * Called when the details for a given item are about to be shown.
     * @param {string} id
     */
    willShowItemDetails: function(id) {
      this.sharedElements = {hero: this.$$('#' + id)};
    },

    /**
     * Updates the size for a given item.
     * @param {CustomEvent} e
     * @private
     * @suppress {checkTypes} Closure doesn't know $.list is an IronList.
     */
    itemSizeChanged_: function(e) {
      this.$.list.updateSizeForItem(e.detail.item);
    },

    /**
     * Called right before an item enters the detailed view.
     * @param {CustomEvent} e
     * @private
     */
    showItemDetails_: function(e) {
      this.sharedElements = {hero: e.detail.element};
    },

    /**
     * Computes the list of items to be shown.
     * @param {Object} changeRecord The changeRecord for |items|.
     * @param {string} filter The updated filter string.
     * @return {Array<!chrome.developerPrivate.ExtensionInfo>}
     * @private
     */
    computeShownItems_: function(changeRecord, filter) {
      return this.items.filter(function(item) {
        return item.name.toLowerCase().includes(this.filter.toLowerCase());
      }, this);
    },
  });

  return {
    ItemList: ItemList,
  };
});
